# Pyxations

<div>
  <img src="static/images/pyxations_improved_logo.png" alt="pyxations logo" style="width: 200px; float: left; margin-right: 20px;"/>
  <p>
    <strong>Pyxations</strong> is a Python library designed to analyze eye-tracking data, whether you are working with raw eye-tracking data or processed datasets. It helps researchers and developers extract useful insights from complex eye movements using Python's robust ecosystem.
  </p>
</div>


## Features

- **BIDS Conversion**: Convert your dataset to BIDS format, automatically organizing files according to BIDS standards.
- **EDF to ASCII Conversion**: Convert EDF files to ASCII format using `edf2asc`, a tool provided by EyeLink.
- **EDF Parsing**: Parse EDF files generated by the EyeLink system to extract various data structures, including header information, messages, calibration data, events, and raw samples.
- **Trial Segmentation**: Segment continuous eye-tracking data into trials using flexible methods, including start/end messages, fixed durations, or explicit start/end times.
- **Derivative Computation**: Compute derivatives for a dataset by parsing EDF files and storing the results in an organized manner.
- **Processing Derivatives**: Process the derivatives by performing eye movement detection, classifying saccades, splitting them into trials, and visualizing the results.
- **Eye Movement Detection**: Detect fixations and saccades using multiple algorithms like REMoDNaV, Engbert–Kliegl, among others.
- **Saccades Direction Classification**: Classify saccades based on their start and end coordinates into four primary directions: right, left, up, and down.

  
## Prerequisites
- Ensure you have Python 3.10 or higher installed. 

- The `edf2asc` software from EyeLink is required for converting EDF files to ASCII format. Please ensure that the EyeLink software is installed and accessible in your system's PATH. The program is provided with the lastest version of the [EyeLink Developers Kit](https://www.sr-research.com/support/thread-7.html)

- To run the script, you also need to install the required Python packages. You can do this by executing the following command:
```bash
pip install -r requirements.txt
```

## Installation

You can install **pyxations** via pip: **[WORK IN PROGRESS]**

```bash
pip install pyxations
```

or from local package:

```bash
cd /path/to/your/package
pip install .
```
If you're developing the package and want changes to the code to be immediately reflected without reinstalling, you can use the -e option to install the package in "editable" mode:

```bash
pip install -e .
```
## Usage
### Minimal example
```python
import pyxations as pyx

pyx.dataset_to_bids(
    target_folder_path=" Path/to/the/folder/where/the/BIDS/dataset/will/be/created", 
    files_folder_path="Path/to/the/folder/containing/the/EDF/files",  
    dataset_name="dataset_name",
)

pyx.compute_derivatives_for_dataset(
    bids_dataset_folder="Path/to/dataset_name",
    msg_keywords=["start_msg", "end_msg"], # multiple msg keywords are allowed
)
```

## Contributing

Contributions are welcome! Please feel free to submit a Pull Request or open an Issue on the [GitHub repository](https://github.com/NeuroLIAA/pyxations).

## License

This project is licensed under the MIT License.
